@@ -15,6 +15,7 @@
 package Google::Ads::AdWords::Utilities::BatchJobHandler;
 
 use strict;
+use warnings;
 use utf8;
 use version;
 
@@ -512,7 +513,7 @@ time that the http client waits to get a response from the server.
 If the timeout is not specified, the default is
 Google::Ads::AdWords::Constants::LWP_DEFAULT_TIMEOUT
 
-= back
+=back
 
 =head3 Returns
 
@@ -570,7 +571,7 @@ time that the http client waits to get a response from the server.
 If the timeout is not specified, the default is
 Google::Ads::AdWords::Constants::LWP_DEFAULT_TIMEOUT
 
-= back
+=back
 
 =head3 Returns
 
@@ -604,6 +605,8 @@ time that the http client waits to get a response from the server.
 If the timeout is not specified, the default is
 Google::Ads::AdWords::Constants::LWP_DEFAULT_TIMEOUT
 
+=back
+
 =head3 Returns
 
 BatchJobOpsService::mutateResponse object with contents from the
